# eric7.WebBrowser.OpenSearch.OpenSearchEngineAction

Module implementing a QAction subclass for open search.

### Global Attributes

None

### Classes

OpenSearchEngineAction | Class implementing a QAction subclass for open search.

### Functions

None

## OpenSearchEngineAction

Class implementing a QAction subclass for open search.

### Derived from

QAction

### Class Attributes

None

### Class Methods

None

### Methods

OpenSearchEngineAction | Constructor
__imageChanged | Private slot handling a change of the associated image.

### Static Methods

None

#### OpenSearchEngineAction (Constructor)

OpenSearchEngineAction(engine, parent=None)

Constructor

engine
  reference to the open search engine object (OpenSearchEngine)
parent
  reference to the parent object (QObject)

#### OpenSearchEngineAction.__imageChanged

__imageChanged()

Private slot handling a change of the associated image.

Up